@@ -53,7 +53,7 @@ CREATE OR REPLACE FUNCTION pc_typmod_pcid(typmod integer)
 
 -- Return the script version number
 CREATE OR REPLACE FUNCTION pc_script_version()
-	RETURNS text AS $$ SELECT '1.2.0'::text $$
+	RETURNS text AS $$ SELECT '1.2.1'::text $$
 	LANGUAGE 'sql' IMMUTABLE STRICT PARALLEL SAFE;
 
 -- Return the library version number
@@ -188,19 +188,6 @@ CREATE OR REPLACE FUNCTION pcpoint_out(pcpoint)
 	RETURNS cstring AS 'MODULE_PATHNAME', 'pcpoint_out'
 	LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE;
 
-CREATE TYPE pcpoint (
-	internallength = variable,
-	input = pcpoint_in,
-	output = pcpoint_out,
-	-- send = geometry_send,
-	-- receive = geometry_recv,
-	typmod_in = pc_typmod_in,
-	typmod_out = pc_typmod_out,
-	-- delimiter = ':',
-	-- alignment = double,
-	-- analyze = geometry_analyze,
-	storage = external -- do not try to compress it please
-);
 
 CREATE OR REPLACE FUNCTION PC_Get(pt pcpoint, dimname text)
 	RETURNS numeric AS 'MODULE_PATHNAME', 'pcpoint_get_value'
@@ -240,19 +227,6 @@ CREATE OR REPLACE FUNCTION pcpatch_out(pcpatch)
 	RETURNS cstring AS 'MODULE_PATHNAME', 'pcpatch_out'
 	LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE;
 
-CREATE TYPE pcpatch (
-	internallength = variable,
-	input = pcpatch_in,
-	output = pcpatch_out,
-	-- send = geometry_send,
-	-- receive = geometry_recv,
-	typmod_in = pc_typmod_in,
-	typmod_out = pc_typmod_out,
-	-- delimiter = ':',
-	-- alignment = double,
-	-- analyze = geometry_analyze,
-	storage = external
-);
 
 CREATE OR REPLACE FUNCTION PC_AsText(p pcpatch)
 	RETURNS text AS 'MODULE_PATHNAME', 'pcpatch_as_text'
@@ -429,13 +403,11 @@ CREATE OR REPLACE FUNCTION pcpatch(p pcpatch, typmod integer, explicit boolean)
 	RETURNS pcpatch AS 'MODULE_PATHNAME', 'pcpatch_enforce_typmod'
 	LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE;
 
-CREATE CAST (pcpatch AS pcpatch) WITH FUNCTION pcpatch(pcpatch, integer, boolean) AS IMPLICIT;
 
 CREATE OR REPLACE FUNCTION pcpoint(p pcpoint, typmod integer, explicit boolean)
 	RETURNS pcpoint AS 'MODULE_PATHNAME', 'pcpoint_enforce_typmod'
 	LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE;
 
-CREATE CAST (pcpoint AS pcpoint) WITH FUNCTION pcpoint(pcpoint, integer, boolean) AS IMPLICIT;
 
 -------------------------------------------------------------------
 --  AGGREGATE GENERIC SUPPORT
@@ -449,12 +421,6 @@ CREATE OR REPLACE FUNCTION pointcloud_abs_out(pointcloud_abs)
 	RETURNS cstring AS 'MODULE_PATHNAME'
 	LANGUAGE 'c' IMMUTABLE STRICT PARALLEL SAFE;
 
-CREATE TYPE pointcloud_abs (
-	internallength = 8,
-	input = pointcloud_abs_in,
-	output = pointcloud_abs_out,
-	alignment = double
-);
 
 -------------------------------------------------------------------
 --  AGGREGATE PCPOINT
@@ -476,23 +442,7 @@ CREATE OR REPLACE FUNCTION pcpoint_agg_final_pcpatch (pointcloud_abs)
 	RETURNS pcpatch AS 'MODULE_PATHNAME', 'pcpoint_agg_final_pcpatch'
 	LANGUAGE 'c' PARALLEL SAFE;
 
-CREATE AGGREGATE PC_Patch(pcpoint) (
-	SFUNC = pcpoint_agg_transfn,
-	STYPE = pointcloud_abs,
 
-	PARALLEL = safe,
-
-	FINALFUNC = pcpoint_agg_final_pcpatch
-);
-
-CREATE AGGREGATE PC_Point_Agg(pcpoint) (
-	SFUNC = pcpoint_agg_transfn,
-	STYPE = pointcloud_abs,
-
-	PARALLEL = safe,
-
-	FINALFUNC = pcpoint_agg_final_array
-);
 
 -------------------------------------------------------------------
 --  AGGREGATE / EXPLODE PCPATCH
@@ -510,23 +460,7 @@ CREATE OR REPLACE FUNCTION pcpatch_agg_transfn (pointcloud_abs, pcpatch)
 	RETURNS pointcloud_abs AS 'MODULE_PATHNAME', 'pointcloud_agg_transfn'
 	LANGUAGE 'c' PARALLEL SAFE;
 
-CREATE AGGREGATE PC_Patch_Agg(pcpatch) (
-	SFUNC = pcpatch_agg_transfn,
-	STYPE = pointcloud_abs,
 
-	PARALLEL = safe,
-
-	FINALFUNC = pcpatch_agg_final_array
-);
-
-CREATE AGGREGATE PC_Union(pcpatch) (
-	SFUNC = pcpatch_agg_transfn,
-	STYPE = pointcloud_abs,
-
-	PARALLEL = safe,
-
-	FINALFUNC = pcpatch_agg_final_pcpatch
-);
 
 CREATE OR REPLACE FUNCTION PC_Explode(p pcpatch)
 	RETURNS setof pcpoint AS 'MODULE_PATHNAME', 'pcpatch_unnest'
